@@ -125,6 +125,7 @@ static GtkDrawingAreaClass *parent_class;
 static void
 draw (GtkWidget *widget, cairo_t *cr)
 {
+	GtkAllocation allocation;
 	double x, y;
 	double radius;
 	double half;
@@ -137,18 +138,22 @@ draw (GtkWidget *widget, cairo_t *cr)
 
 	cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
 
-	width = widget->allocation.width;
-	height = widget->allocation.height;
+	gtk_widget_get_allocation (widget, &allocation);
+	width = allocation.width;
+	height = allocation.height;
 
-	if ( (width < 12) || (height <12) )
+	if ( (width < 12) || (height <12) ) {
 		gtk_widget_set_size_request(widget, 12, 12);
+		gtk_widget_get_allocation (widget, &allocation);
+		width = allocation.width;
+		height = allocation.height;
+	}
 
-	//x = widget->allocation.x + widget->allocation.width / 2;
-	//y = widget->allocation.y + widget->allocation.height / 2;
-	x = widget->allocation.width / 2;
-	y = widget->allocation.height / 2;
-	radius = MIN (widget->allocation.width	/ 2,
-				  widget->allocation.height / 2);
+	/* x = widget->allocation.x + widget->allocation.width / 2;
+	 * y = widget->allocation.y + widget->allocation.height / 2; */
+	x = width / 2;
+	y = height / 2;
+	radius = MIN (width / 2, height / 2);
 	half = priv->lines / 2;
 
 	/*FIXME: render in B&W for non transparency */
@@ -217,7 +222,7 @@ gdu_spinner_init (GduSpinner *spinner)
 	priv->current = 0;
 	priv->timeout = 0;
 
-	GTK_WIDGET_SET_FLAGS (GTK_WIDGET (spinner), GTK_NO_WINDOW);
+	gtk_widget_set_has_window (GTK_WIDGET (spinner), FALSE);
 }
 
 static gboolean
@@ -226,7 +231,7 @@ gdu_spinner_expose (GtkWidget *widget, GdkEventExpose *event)
 	cairo_t *cr;
 
 	/* get cairo context */
-	cr = gdk_cairo_create (widget->window);
+	cr = gdk_cairo_create (gtk_widget_get_window (widget));
 
 	/* set a clip region for the expose event */
 	cairo_rectangle (cr,
