@@ -680,6 +680,16 @@ gdu_drive_get_name (GduPresentable *presentable)
                 strsize = gdu_util_get_size_for_display (size, FALSE, FALSE);
         }
 
+        if (gdu_device_is_linux_loop (drive->priv->device)) {
+                /* Translators: This is the name of a "Drive" backed by a file.
+                 * The %s is the size of the file (e.g. "42 GB" or "5 KB").
+                 *
+                 * See e.g. http://people.freedesktop.org/~david/gnome-loopback-2.png
+                 */
+                g_string_append_printf (result, _("%s File"), strsize);
+                goto out;
+        }
+
         if (is_removable) {
 
                 get_drive_name_from_media_compat (drive->priv->device, result);
@@ -851,6 +861,14 @@ gdu_drive_get_vpd_name (GduPresentable *presentable)
 
         result = g_string_new (NULL);
 
+        if (gdu_device_is_linux_loop (drive->priv->device)) {
+                gchar *s;
+                s = g_path_get_basename (gdu_device_linux_loop_get_filename (drive->priv->device));
+                g_string_append (result, s);
+                g_free (s);
+                goto out;
+        }
+
         vendor = gdu_device_drive_get_vendor (drive->priv->device);
         model = gdu_device_drive_get_model (drive->priv->device);
 
@@ -866,6 +884,7 @@ gdu_drive_get_vpd_name (GduPresentable *presentable)
                                 vendor != NULL ? " " : "",
                                 model != NULL ? model : "");
 
+ out:
         return g_string_free (result, FALSE);
 }
 
@@ -932,6 +951,11 @@ gdu_drive_get_icon (GduPresentable *presentable)
                 goto out;
         }
 
+        if (gdu_device_is_linux_loop (drive->priv->device)) {
+                name = "drive-removable-media-file";
+                goto out;
+        }
+
         /* media type */
         if (strv_has (drive_media_compat, "optical_cd")) {
                 /* TODO: it would probably be nice to export a property whether this device can
